
use crate::{GITEA_KEY, gitea::{User, Repo}};

macro_rules! gitea_api {
    ($path: expr) => {
        format!("{}{}?token={}", dotenvy_macro::dotenv!("GITEA_URL", "Gitea url is not set!"), $path, GITEA_KEY)
    };
}

pub async fn get_user() -> User {
    let user = reqwest::get(gitea_api!("/api/v1/user")).await.unwrap();

    if user.status() != 200 {
        panic!("Request failed with code {}", user.status());
    }

    let user = user.bytes().await.unwrap();
    let user = String::from_utf8(user.to_vec()).unwrap();
    serde_json::from_str::<User>(user.as_str()).unwrap()
}

pub async fn get_org_repos(org: String) -> Vec<Repo> {
    let repos = reqwest::get(gitea_api!(format!("/api/v1/orgs/{org}/repos"))).await.unwrap();

    if repos.status() != 200 {
        panic!("Request failed with code {}", repos.status());
    }

    let repos = repos.bytes().await.unwrap();
    let repos = String::from_utf8(repos.to_vec()).unwrap();

    serde_json::from_str::<Vec<Repo>>(repos.as_str()).unwrap()
}

pub fn filter_repos(repos: Vec<Repo>) -> Vec<Repo> {
    repos.iter().filter_map(|x| { if (!x.archived) && x.has_pull_requests { Some(x) } else { None } }).collect::<Vec<Repo>>()
}